@@ -4,7 +4,7 @@ from transifex.native.core import TxNative
 def init(
     token, languages, secret=None,
     cds_host=None, missing_policy=None,
-    error_policy=None
+    error_policy=None, cache=None,
 ):
     """Initialize the framework.
 
@@ -18,6 +18,7 @@ def init(
         for returning strings when a translation is missing
     :param AbstractErrorPolicy error_policy: an optional policy to use
         for defining how to handle translation rendering errors
+        :param AbstractCache cache: an optional cache
     """
     if not tx.initialized:
         tx.init(
@@ -26,7 +27,8 @@ def init(
             secret=secret,
             cds_host=cds_host,
             missing_policy=missing_policy,
-            error_policy=error_policy
+            error_policy=error_policy,
+            cache=cache,
         )
 
 
