@@ -6,18 +6,25 @@ from django.conf import settings
 from django.template import Library, Node, TemplateSyntaxError
 from django.template.base import (BLOCK_TAG_END, BLOCK_TAG_START,
                                   COMMENT_TAG_END, COMMENT_TAG_START,
-                                  TOKEN_BLOCK, TOKEN_COMMENT, TOKEN_TEXT,
-                                  TOKEN_VAR, VARIABLE_TAG_END,
-                                  VARIABLE_TAG_START)
+                                  VARIABLE_TAG_END, VARIABLE_TAG_START)
 from django.template.defaulttags import token_kwargs
 from django.utils.html import escape as escape_html
-from django.utils.safestring import EscapeData, SafeData, mark_safe
+from django.utils.safestring import SafeData, mark_safe
 from django.utils.translation import get_language, to_locale
 from transifex.common._compat import string_types
 from transifex.native import tx
+from transifex.native.django.compat import (TOKEN_BLOCK, TOKEN_COMMENT,
+                                            TOKEN_TEXT, TOKEN_VAR)
 
 from .utils import get_icu_keys
 
+try:
+    from django.utils.safestring import EscapeData
+except ImportError:
+    class EscapeData(object):
+        pass
+
+
 register = Library()
 
 
@@ -192,13 +199,16 @@ class TNode(Node):
 
         # Perform the translation in two steps: First, we get the translation
         # ICU template. Then we perform ICU rendering against 'params'.
-        # Inbetween the two steps, if the tag used was 't' and not 'ut', we
-        # peform escaping on the ICU template.
+        # In between the two steps, if the tag used was 't' and not 'ut', we
+        # perform escaping on the ICU template.
         is_source = get_language() == settings.LANGUAGE_CODE
         locale = to_locale(get_language())  # e.g. from en-us to en_US
         translation_icu_template = tx.get_translation(
-            source_icu_template, locale, params.get('_context', None),
-            is_source,
+            source_string=source_icu_template,
+            language_code=locale,
+            _context=params.get('_context', None),
+            is_source=is_source,
+            _key=params.get('_key', None),
         )
 
         # The ICU template can compile against explicitly passed params as well
